ResultMarkdown class

ResultMarkdown give you the converted data to markdown and the cursorIndex

Constructors

ResultMarkdown(String data, int cursorIndex, int replaceCursorIndex)
Return ResultMarkdown

Properties

cursorIndex ↔ int
cursor index just after the converted part in markdown
getter/setter pair
data ↔ String
String converted to mardown
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
replaceCursorIndex ↔ int
index at which cursor need to be replaced if no text selected
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited